@@ -14,21 +14,21 @@ use File::Spec::Functions qw(catfile splitpath);
 my @fields;
 
 BEGIN {
-	our $VERSION = "0.05_01";
-	$VERSION = eval $VERSION;
+	our $VERSION = 0.02;
+	$VERSION = eval "$VERSION";
 	@fields = qw(filename flags mode packformat handle
 	reclen nulls nulla);
 	__PACKAGE__->mk_accessors(@fields);
 	*fh = \&handle;
-	# require Tie::FlatFile::ArrayHelper;
+	require Tie::FlatFile::ArrayHelper;
 }
 
 sub TIEARRAY {
 	my $class = shift;
 	my $self = bless({}, $class);
+	# my ($filename, $flags, $mode, $packformat) = @_;
 	my ($filename, $flags, $mode, $opts) = @_;
 	my ($packformat);
-	local $Carp::CarpLevel = 1;	# Set the stack frame for croak().
 
 	if ('HASH' ne ref($opts)) {
 		croak('Options hash missing');
@@ -69,16 +69,13 @@ sub UNTIE {
 
 sub FETCH {
 	my ($self, $index) = @_;
-	return undef if $index < 0;
-
 	my $len = $self->reclen;
 	my $fh = $self->fh;
-	local $Carp::CarpLevel = 1;	# Set the stack frame for croak().
 
 	local $RS = \$len;		# Set the record length.
 	seek($fh, $index * $len, SEEK_SET);
 	my $data = <$fh>;  # Get a record.
-	return undef unless $data;
+	croak("Index $index: Invalid access of $fh") unless $data;
 
 	# Unpack and return the data as an array reference.
 	[ unpack $self->packformat, $data ];
@@ -179,5 +176,6 @@ sub UNSHIFT {
 }
 
 
+
 1;
 
